#[repr(C)]pub struct DispatcherDebugStats {
pub num_total_requests: u64,
pub num_inlined_requests: u64,
pub non_inlined: NonInlinedRequestStats,
}Expand description
Request and inlining statistics for a dispatcher.
Fields
num_total_requests: u64num_inlined_requests: u64non_inlined: NonInlinedRequestStatsTrait Implementations
Sourceimpl Clone for DispatcherDebugStats
impl Clone for DispatcherDebugStats
Sourcefn clone(&self) -> DispatcherDebugStats
fn clone(&self) -> DispatcherDebugStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DispatcherDebugStats
Sourceimpl Debug for DispatcherDebugStats
impl Debug for DispatcherDebugStats
Sourceimpl<D: ResourceDialect> Decode<DispatcherDebugStats, D> for DispatcherDebugStats
impl<D: ResourceDialect> Decode<DispatcherDebugStats, D> for DispatcherDebugStats
Sourceimpl<D: ResourceDialect> Encode<DispatcherDebugStats, D> for &DispatcherDebugStats
impl<D: ResourceDialect> Encode<DispatcherDebugStats, D> for &DispatcherDebugStats
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<u64, D>, T2: Encode<NonInlinedRequestStats, D>> Encode<DispatcherDebugStats, D> for (T0, T1, T2)
impl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<u64, D>, T2: Encode<NonInlinedRequestStats, D>> Encode<DispatcherDebugStats, D> for (T0, T1, T2)
impl Eq for DispatcherDebugStats
Sourceimpl Hash for DispatcherDebugStats
impl Hash for DispatcherDebugStats
Sourceimpl Ord for DispatcherDebugStats
impl Ord for DispatcherDebugStats
Sourcefn cmp(&self, other: &DispatcherDebugStats) -> Ordering
fn cmp(&self, other: &DispatcherDebugStats) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for DispatcherDebugStats
impl PartialEq for DispatcherDebugStats
Sourceimpl PartialOrd for DispatcherDebugStats
impl PartialOrd for DispatcherDebugStats
impl Persistable for DispatcherDebugStats
impl StructuralPartialEq for DispatcherDebugStats
Sourceimpl TypeMarker for DispatcherDebugStats
impl TypeMarker for DispatcherDebugStats
Sourcetype Owned = DispatcherDebugStats
type Owned = DispatcherDebugStats
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for DispatcherDebugStats
impl ValueTypeMarker for DispatcherDebugStats
Sourcetype Borrowed<'a> = &'a DispatcherDebugStats
type Borrowed<'a> = &'a DispatcherDebugStats
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for DispatcherDebugStats
impl RefUnwindSafe for DispatcherDebugStats
impl Send for DispatcherDebugStats
impl Sync for DispatcherDebugStats
impl Unpin for DispatcherDebugStats
impl UnsafeUnpin for DispatcherDebugStats
impl UnwindSafe for DispatcherDebugStats