#[repr(C)]pub struct NonInlinedRequestStats {
pub allow_sync_calls: u64,
pub parallel_dispatch: u64,
pub task: u64,
pub unknown_thread: u64,
pub reentrant: u64,
pub channel_wait_not_yet_registered: u64,
pub no_thread_migration: u64,
}Expand description
Breakdown of reasons why requests were not inlined by the driver runtime.
Fields
allow_sync_calls: u64parallel_dispatch: u64task: u64unknown_thread: u64reentrant: u64channel_wait_not_yet_registered: u64no_thread_migration: u64Trait Implementations
Sourceimpl Clone for NonInlinedRequestStats
impl Clone for NonInlinedRequestStats
Sourcefn clone(&self) -> NonInlinedRequestStats
fn clone(&self) -> NonInlinedRequestStats
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for NonInlinedRequestStats
Sourceimpl Debug for NonInlinedRequestStats
impl Debug for NonInlinedRequestStats
Sourceimpl<D: ResourceDialect> Decode<NonInlinedRequestStats, D> for NonInlinedRequestStats
impl<D: ResourceDialect> Decode<NonInlinedRequestStats, D> for NonInlinedRequestStats
Sourceimpl<D: ResourceDialect> Encode<NonInlinedRequestStats, D> for &NonInlinedRequestStats
impl<D: ResourceDialect> Encode<NonInlinedRequestStats, D> for &NonInlinedRequestStats
Sourceimpl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<u64, D>, T2: Encode<u64, D>, T3: Encode<u64, D>, T4: Encode<u64, D>, T5: Encode<u64, D>, T6: Encode<u64, D>> Encode<NonInlinedRequestStats, D> for (T0, T1, T2, T3, T4, T5, T6)
impl<D: ResourceDialect, T0: Encode<u64, D>, T1: Encode<u64, D>, T2: Encode<u64, D>, T3: Encode<u64, D>, T4: Encode<u64, D>, T5: Encode<u64, D>, T6: Encode<u64, D>> Encode<NonInlinedRequestStats, D> for (T0, T1, T2, T3, T4, T5, T6)
impl Eq for NonInlinedRequestStats
Sourceimpl Hash for NonInlinedRequestStats
impl Hash for NonInlinedRequestStats
Sourceimpl Ord for NonInlinedRequestStats
impl Ord for NonInlinedRequestStats
Sourcefn cmp(&self, other: &NonInlinedRequestStats) -> Ordering
fn cmp(&self, other: &NonInlinedRequestStats) -> Ordering
1.21.0 (const: unstable) · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
1.21.0 (const: unstable) · Sourcefn min(self, other: Self) -> Selfwhere
Self: Sized,
fn min(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the minimum of two values. Read more
Sourceimpl PartialEq for NonInlinedRequestStats
impl PartialEq for NonInlinedRequestStats
Sourceimpl PartialOrd for NonInlinedRequestStats
impl PartialOrd for NonInlinedRequestStats
impl Persistable for NonInlinedRequestStats
impl StructuralPartialEq for NonInlinedRequestStats
Sourceimpl TypeMarker for NonInlinedRequestStats
impl TypeMarker for NonInlinedRequestStats
Sourcetype Owned = NonInlinedRequestStats
type Owned = NonInlinedRequestStats
The owned Rust type which this FIDL type decodes into.
Sourcefn inline_align(_context: Context) -> usize
fn inline_align(_context: Context) -> usize
Returns the minimum required alignment of the inline portion of the
encoded object. It must be a (nonzero) power of two.
Sourcefn inline_size(_context: Context) -> usize
fn inline_size(_context: Context) -> usize
Returns the size of the inline portion of the encoded object, including
padding for alignment. Must be a multiple of
inline_align.Sourcefn encode_is_copy() -> bool
fn encode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and encoding requires no validation. When true, we can optimize
encoding arrays and vectors of Self::Owned to a single memcpy. Read moreSourcefn decode_is_copy() -> bool
fn decode_is_copy() -> bool
Returns true if the memory layout of
Self::Owned matches the FIDL wire
format and decoding requires no validation. When true, we can optimize
decoding arrays and vectors of Self::Owned to a single memcpy.Sourceimpl ValueTypeMarker for NonInlinedRequestStats
impl ValueTypeMarker for NonInlinedRequestStats
Sourcetype Borrowed<'a> = &'a NonInlinedRequestStats
type Borrowed<'a> = &'a NonInlinedRequestStats
The Rust type to use for encoding. This is a particular
Encode<Self>
type cheaply obtainable from &Self::Owned. There are three cases: Read moreAuto Trait Implementations
impl Freeze for NonInlinedRequestStats
impl RefUnwindSafe for NonInlinedRequestStats
impl Send for NonInlinedRequestStats
impl Sync for NonInlinedRequestStats
impl Unpin for NonInlinedRequestStats
impl UnsafeUnpin for NonInlinedRequestStats
impl UnwindSafe for NonInlinedRequestStats